@@ -5,12 +5,17 @@ our $ARGS       = undef;
 our $CONFIG_FOO = undef;
 our $TESTED     = 0;
 
+has foo => (
+    is  => 'ro',
+    isa => 'Any',
+);
+
 hook 'test2' => sub {
     my ($self, $c, $args) = @_;
     $TESTED=1;
     $CONTEXT = $c;
     $ARGS = $args;
-    $CONFIG_FOO = $self->config->{foo};
+    $CONFIG_FOO = $self->foo;
 };
 
 1;
